<?php

namespace itguild\forms\inputs;

use itguild\forms\debug\Debug;
use itguild\forms\traits\CreateOption;
use itguild\forms\traits\CreateParams;
use itguild\forms\inputs\BaseInput;

class Select extends BaseInput
{
    use CreateParams;
    use CreateOption;
    private $name;
    private $options;

    private bool $hasLabel = false;
    private string $labelTitle = '';
    private $value;
    private $paramsArray;


    /**
     * @param string $name
     * @param array $options
     * @param $value
     * @param array $paramsArray
     */
    public function __construct(string $name, array $options = [], $value = null, array $paramsArray = [])
    {
        $this->name = $name;
        $this->options = $options;
        $this->value = $value;
        $this->paramsArray = $paramsArray;
    }

    /**
     * @return $this
     */
    public function create(): self
    {
        $paramsString  = $this->createParams($this->paramsArray);
        $optionsString = $this->createOption($this->options, $this->value);
        $this->html = "<select name='$this->name' $paramsString>$optionsString</select>";
        if($this->hasLabel == true) {
            $this->html = "<label>$this->labelTitle</label> $this->html";
        }

        return $this;

    }

    /**
     * @param string $name
     * @param array $options
     * @param $value
     * @param array $paramsArray
     * @return void
     */
    public static function build(string $name, array $options = [], $value = null, array $paramsArray = []): void
    {
        $textarea = new self($name, $options, $value, $paramsArray);
        $textarea->create()->render();
    }

    /**
     * @param string $title
     * @return $this
     */
    public function setLabel(string $title): self
    {
        $this->hasLabel = true;
        $this->labelTitle = $title;

        return $this;
    }

    /**
     * @param $options
     * @return $this
     */
    public function setOptions($options)
    {
        $this->options = array_merge($options, $this->options);
        return $this;
    }
}