<?php

namespace itguild\forms\inputs;

use itguild\forms\traits\CreateParams;
use itguild\forms\inputs\BaseInput;

class TextArea extends BaseInput
{
    use CreateParams;

    private $name;
    private $value;
    private $paramsArray;
    private bool $hasLabel = false;
    private string $labelTitle = '';

    /**
     * @param string $name
     * @param string $value
     * @param array $paramsArray
     */
    public function __construct(string $name, string $value = '', array $paramsArray = [])
    {
        $this->name = $name;
        $this->value = $value;
        $this->paramsArray = $paramsArray;
    }

    /**
     * @return $this
     */
    public function create(): self
    {
        $paramsString = $this->createParams($this->paramsArray);
        $this->html = "<textarea name='$this->name' $paramsString>$this->value</textarea>";
        if($this->hasLabel == true) {
            $this->html = "<label>$this->labelTitle</label> $this->html";
        }

        return $this;
    }


    /**
     * @param string $name
     * @param string $value
     * @param array $paramsArray
     * @return void
     */
    public static function build(string $name, string $value, array $paramsArray = []): void
    {
        $textarea = new self($name, $value, $paramsArray);
        $textarea->create()->render();
    }

    /**
     * @param string $title
     * @return $this
     */
    public function setLabel(string $title): self
    {
        $this->hasLabel = true;
        $this->labelTitle = $title;

        return $this;
    }


}